#!/bin/sh

usage() {
    echo -e -n "\n"
    echo "artifactIndexFullReindex.sh [options...]"
    echo -e -n "\n"
    echo "Options:"
    echo "    -?, -help                             print this message"
    echo "    -u <username>, -username <username>   user name of admin user"
    echo "    -p <password>, -password <password>   user password (unencrypted), must be used with username"
    echo "    -host                                 server host name, must be used with port"
    echo "    -port                                 server SOAP port number"
    echo -e -n "\n"
    exit $1
}

USERNAME_ARG=
PASSWORD_ARG=
USER_INSTALL_ROOT=
HOSTNAME=
SERVERPORT=

FINISHED='0'
until [ "$#" = "0" -o $FINISHED = '1' ]
do
    case "$1" in
        '-help'|'-?')
            usage 0
            ;;
        '-USER_INSTALL_ROOT')
            USER_INSTALL_ROOT="$2"
            shift;shift
            ;;
        '-username'|'-u'|'-user')
            USERNAME_ARG="$2"
            shift;shift
            ;;
        '-password'|'-p')
            PASSWORD_ARG="$2"
            shift;shift
            ;;
        '-host')
            HOSTNAME="$2"
            shift;shift
            ;;
        '-port')
            SERVERPORT="$2"
            shift;shift
            ;;
        *)  
            if [ "$1" ]
	        then
	           usage 1
	        fi        
            FINISHED='1'
            ;;
    esac
done

# if username is specified, password is required
SECURITY_PARM=
if [ -n "$USERNAME_ARG" ]
then
   if [ -n "$PASSWORD_ARG" ]
   then
      SECURITY_PARM="-user $USERNAME_ARG -password $PASSWORD_ARG"
   else
      echo -e -n "\n"
      echo "-username and -password both must be specified"
      usage 1
   fi
else
   echo -e -n "\n"
   echo "-username and -password both must be specified"
   usage 1
fi

# if hostname is specified, port is required
if [ -n "$HOSTNAME" ]
then
   if [ -z "$SERVERPORT" ]
   then
      echo -e -n "\n"
      echo "-host and -port both must be specified"
      usage 1
   fi
else
   if [ -n "$SERVERPORT" ]
   then
      echo -e -n "\n"
      echo "-host and -port both must be specified"
      usage 1
   fi
fi

if [ -n "$HOSTNAME" ]
then
	$USER_INSTALL_ROOT/bin/wsadmin.sh -lang jython -wsadmin_classpath $WAS_HOME"/BPM/Lombardi/lib/ps.jar":$WAS_HOME"/BPM/Lombardi/lib/utility.jar" $SECURITY_PARM -conntype SOAP -host $HOSTNAME -port $SERVERPORT -f $WAS_HOME"/BPM/Lombardi/tools/search-index/artifactIndexFullReindex.jy"

else
	$USER_INSTALL_ROOT/bin/wsadmin.sh -lang jython -wsadmin_classpath $WAS_HOME"/BPM/Lombardi/lib/ps.jar":$WAS_HOME"/BPM/Lombardi/lib/utility.jar" $SECURITY_PARM -f $WAS_HOME"/BPM/Lombardi/tools/search-index/artifactIndexFullReindex.jy"  

fi


if [ "$?" -ne "0" ]
then
    echo "Failed, please see logs for further details."
    echo -e -n "\n"
    exit $?
fi
