#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

echo ""
echo "IBM Business Process Manager 8.5.0 Upgrade"
echo ""

setWASHome()
{
    if [ "${REPLACE_WAS_HOME:=}" != "" ] && [ -d ${REPLACE_WAS_HOME} ]
    then
        WAS_HOME=${REPLACE_WAS_HOME}
    else
        CUR_DIR=`pwd`
        WAS_DIR=`dirname ${0}`/../
        cd "${WAS_DIR}"
        WAS_HOME=`pwd`
        cd "${CUR_DIR}"
    fi
}

usage() {
  echo -e -n "\n"
  echo "Starts or continues the upgrade."
  echo -e -n "\n"
  echo "Usage:"
  echo -e -n "\n"
  echo "   `basename ${0}` [options...]"
  echo -e -n "\n"
  echo "Options:"
  echo "   -?, -help                             This help message"
  echo "   -propertiesFile  <full path>          Full path of migration properties file"
  echo "   -backupFolder <directory>             Directory of backup folder from source environment"
  echo "   -noPrompt                             Set -noPrompt flag to make the tool work with no interaction. If you do not set this parameter, the tool will prompt you to confirm (optional)"		
  echo -e -n "\n"
  exit $1
}

validateParam() {
  if [ "$2" = "" ]
  then
    echo "No value specified for parameter $1"
    usage 1
  fi
}

setWASHome

JAVA_HOME=$WAS_HOME/java
UPGRADECOMMAND_PROP="-Dupgradecommand=$0 $*"

ENABLE_DEBUG=false
if [ $ENABLE_DEBUG = true ]; then
   DEBUG_PROP="-Xdebug -Xrunjdwp:transport=dt_socket,address=7780,server=y,suspend=n"   
else
   DEBUG_PROP= 
fi

FINISHED='0'
PROPERTIES_FILE=
until [ $FINISHED = '1' ]
do
  case "$1" in
    '-?'|'-help')
      usage 0
      ;;
    '-propertiesFile')
      validateParam $1 $2
      MIGRATION_PROPERTIES_FILE="-DpropertiesFile=$2"
      PROPERTIES_FILE="$2"
      shift;shift
      ;;
    '-backupFolder')
      validateParam $1 $2
      BACKUP_FOLDER_PROP="-DbackupFolder=$2"
      shift;shift
      ;;
    '-noPrompt')
      NO_PROMPT_PROP="-DnoPrompt=true"
      shift
      ;;
    *)
      if [ "$1" != "" ]
      then
        echo "Invalid parameter: $1, please correct it and try again."
        usage 1
      fi
      FINISHED='1'
      ;;
  esac
done

DBUPGRADE_RESOURCE_DIR=${WAS_HOME}/util/dbUpgrade

if [ -f ${JAVA_HOME}/bin/java ]; then
  JAVA_EXE="${JAVA_HOME}/bin/java"
else
  JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

WAS_HOME_PROP="-Dwas.install.root=${WAS_HOME}"
APP_JAVA_POLICY="-Djava.security.policy=file:${DBUPGRADE_RESOURCE_DIR}/java.policy"
LOGGING_PROP="-Dcom.lombardisoftware.ant.JULDefaultLogger.level=DEBUG -Djava.util.logging.config.file=$DBUPGRADE_RESOURCE_DIR/logging.properties -Dtw.log4j.init=false"
LOGGING_FILTER_PROP="-Dcom.ibm.bpm.migration.logging.StringFilter.excludes=contains(db.password);equals(WSVR0072W);equals(WSVR0801I);equals(WKSP0500);equals(WSVR0643I);regexp(^Class.+loaded.from.ant.loader..parentFirst.);regexp(^Class.+loaded.from.parent.loader..parentFirst.);regexp(^Finding.class.+\..+\..+);regexp(^Loaded.from.+\.jar..+\.class$)"
LOGGING_PROP="$LOGGING_PROP $LOGGING_FILTER_PROP"
ANT_PROPS="-q -e -logger com.lombardisoftware.ant.JULDefaultLogger"

COMMAND_NAME=`basename $0`
COMMAND_NAME="${COMMAND_NAME%.*}"
COMMAND_NAME_PROPS=-Dmig.command.name="${COMMAND_NAME}"

CLASSPATH=$DBUPGRADE_RESOURCE_DIR
CLASSPATH=$CLASSPATH:$DBUPGRADE_RESOURCE_DIR/lib/ant.jar
CLASSPATH=$CLASSPATH:$DBUPGRADE_RESOURCE_DIR/lib/ant-launcher.jar
CLASSPATH=$CLASSPATH:$DBUPGRADE_RESOURCE_DIR/lib/ant-nodeps.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/ant-contrib.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/twant.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.bpm.migration.logging.jar

CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ffdc.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.hpel.logging.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.admin.core.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.admin.services.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.bootstrap.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.emf.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.javaee.dd.common.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.javaee.dd.ejb.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.runtime.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.wccm.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.wlm.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.wsfp.main.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.wsspi.extension.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.core.runtime_.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.common_.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.registry.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.osgi_.jar

CLASSPATH=$CLASSPATH:$WAS_HOME/lib/bootstrap.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/lib/j2ee.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/org.eclipse.emf.ecore.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/org.eclipse.emf.common.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/org.eclipse.emf.ecore.xmi.jar

$JAVA_EXE -cp $CLASSPATH $WAS_HOME_PROP $APP_JAVA_POLICY $COMMAND_NAME_PROPS $MIGRATION_PROPERTIES_FILE $BACKUP_FOLDER_PROP $NO_PROMPT_PROP $LOGGING_PROP $DEBUG_PROP "$UPGRADECOMMAND_PROP" org.apache.tools.ant.Main -buildfile $DBUPGRADE_RESOURCE_DIR/upgrade.xml $ANT_PROPS

